@@ -88,7 +88,6 @@ where
 
 #[derive(Debug)]
 pub struct SliceByLine<'s, M, S> {
-    config: &'s Config,
     core: Core<'s, M, S>,
     slice: &'s [u8],
 }
@@ -103,7 +102,6 @@ impl<'s, M: Matcher, S: Sink> SliceByLine<'s, M, S> {
         debug_assert!(!searcher.multi_line_with_matcher(&matcher));
 
         SliceByLine {
-            config: &searcher.config,
             core: Core::new(searcher, matcher, write_to, true),
             slice: slice,
         }
@@ -1514,4 +1512,31 @@ and exhibited clearly, with a label attached.\
             )
             .unwrap();
     }
+
+    // See: https://github.com/BurntSushi/ripgrep/issues/2260
+    #[test]
+    fn regression_2260() {
+        use grep_regex::RegexMatcherBuilder;
+
+        use crate::SearcherBuilder;
+
+        let matcher = RegexMatcherBuilder::new()
+            .line_terminator(Some(b'\n'))
+            .build(r"^\w+$")
+            .unwrap();
+        let mut searcher = SearcherBuilder::new().line_number(true).build();
+
+        let mut matched = false;
+        searcher
+            .search_slice(
+                &matcher,
+                b"GATC\n",
+                crate::sinks::UTF8(|_, _| {
+                    matched = true;
+                    Ok(true)
+                }),
+            )
+            .unwrap();
+        assert!(matched);
+    }
 }
